[empathy: 1/4] dispatcher: allow not caring about handle type when looking up RCCs



commit 7d8f163d8dcb540f611b3581389e2c15971e479f
Author: Jonny Lamb <jonnylamb gnome org>
Date:   Wed Mar 10 18:34:34 2010 +0000

    dispatcher: allow not caring about handle type when looking up RCCs
    
    Signed-off-by: Jonny Lamb <jonnylamb gnome org>

 libempathy/empathy-dispatcher.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)
---
diff --git a/libempathy/empathy-dispatcher.c b/libempathy/empathy-dispatcher.c
index caf697c..1edefe9 100644
--- a/libempathy/empathy-dispatcher.c
+++ b/libempathy/empathy-dispatcher.c
@@ -1808,7 +1808,7 @@ channel_class_matches (GValueArray *class,
   h_type = tp_asv_get_uint32 (fprops,
                               TP_IFACE_CHANNEL ".TargetHandleType", &valid);
 
-  if (!valid || handle_type != h_type)
+  if (!valid || (handle_type != h_type && handle_type != TP_UNKNOWN_HANDLE_TYPE))
     return FALSE;
 
   if (fixed_properties != NULL)
@@ -1978,7 +1978,8 @@ setup_varargs (va_list var_args,
  * @dispatcher: an #EmpathyDispatcher
  * @connection: a #TpConnection
  * @channel_type: a string identifying the type of the channel to lookup
  * @handle_type: the handle type for the channel
  * @first_property_name: %NULL, or the name of the first fixed property,
  * followed optionally by more names, followed by %NULL.
  *
@@ -1978,7 +1978,8 @@ setup_varargs (va_list var_args,
  * @connection: a #TpConnection
  * @channel_type: a string identifying the type of the channel to lookup
- * @handle_type: the handle type for the channel
+ * @handle_type: the handle type for the channel, or %TP_UNKNOWN_HANDLE_TYPE
+ *               if you don't care about the channel's target handle type
  * @first_property_name: %NULL, or the name of the first fixed property,
  * followed optionally by more names, followed by %NULL.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]